@@ -393,7 +393,7 @@ HWY_NOINLINE void TestAllZip() {
   lower_unsigned(uint8_t());
 #endif
   lower_unsigned(uint16_t());
-#if HWY_CAP_INTEGER64
+#if HWY_HAVE_INTEGER64
   lower_unsigned(uint32_t());  // generates u64
 #endif
 
@@ -402,7 +402,7 @@ HWY_NOINLINE void TestAllZip() {
   lower_signed(int8_t());
 #endif
   lower_signed(int16_t());
-#if HWY_CAP_INTEGER64
+#if HWY_HAVE_INTEGER64
   lower_signed(int32_t());  // generates i64
 #endif
 
@@ -411,7 +411,7 @@ HWY_NOINLINE void TestAllZip() {
   upper_unsigned(uint8_t());
 #endif
   upper_unsigned(uint16_t());
-#if HWY_CAP_INTEGER64
+#if HWY_HAVE_INTEGER64
   upper_unsigned(uint32_t());  // generates u64
 #endif
 
@@ -420,19 +420,20 @@ HWY_NOINLINE void TestAllZip() {
   upper_signed(int8_t());
 #endif
   upper_signed(int16_t());
-#if HWY_CAP_INTEGER64
+#if HWY_HAVE_INTEGER64
   upper_signed(int32_t());  // generates i64
 #endif
 
   // No float - concatenating f32 does not result in a f64
 }
 
-template <int kBytes>
-struct TestCombineShiftRightBytesR {
-  template <class T, class D>
-  HWY_NOINLINE void operator()(T t, D d) {
 // Scalar does not define CombineShiftRightBytes.
 #if HWY_TARGET != HWY_SCALAR || HWY_IDE
+
+template <int kBytes>
+struct TestCombineShiftRightBytes {
+  template <class T, class D>
+  HWY_NOINLINE void operator()(T, D d) {
     const size_t kBlockSize = 16;
     static_assert(kBytes < kBlockSize, "Shift count is per block");
     const Repartition<uint8_t, D> d8;
@@ -461,21 +462,13 @@ struct TestCombineShiftRightBytesR {
       const auto expected = BitCast(d, Load(d8, expected_bytes.get()));
       HWY_ASSERT_VEC_EQ(d, expected, CombineShiftRightBytes<kBytes>(d, hi, lo));
     }
-
-    TestCombineShiftRightBytesR<kBytes - 1>()(t, d);
-#else
-    (void)t;
-    (void)d;
-#endif  // #if HWY_TARGET != HWY_SCALAR
   }
 };
 
 template <int kLanes>
-struct TestCombineShiftRightLanesR {
+struct TestCombineShiftRightLanes {
   template <class T, class D>
-  HWY_NOINLINE void operator()(T t, D d) {
-// Scalar does not define CombineShiftRightBytes (needed for *Lanes).
-#if HWY_TARGET != HWY_SCALAR || HWY_IDE
+  HWY_NOINLINE void operator()(T, D d) {
     const Repartition<uint8_t, D> d8;
     const size_t N8 = Lanes(d8);
     if (N8 < 16) return;
@@ -505,33 +498,29 @@ struct TestCombineShiftRightLanesR {
       const auto expected = BitCast(d, Load(d8, expected_bytes.get()));
       HWY_ASSERT_VEC_EQ(d, expected, CombineShiftRightLanes<kLanes>(d, hi, lo));
     }
-
-    TestCombineShiftRightLanesR<kLanes - 1>()(t, d);
-#else
-    (void)t;
-    (void)d;
-#endif  // #if HWY_TARGET != HWY_SCALAR
   }
 };
 
-template <>
-struct TestCombineShiftRightBytesR<0> {
-  template <class T, class D>
-  void operator()(T /*unused*/, D /*unused*/) {}
-};
-
-template <>
-struct TestCombineShiftRightLanesR<0> {
-  template <class T, class D>
-  void operator()(T /*unused*/, D /*unused*/) {}
-};
+#endif  // #if HWY_TARGET != HWY_SCALAR
 
 struct TestCombineShiftRight {
   template <class T, class D>
   HWY_NOINLINE void operator()(T t, D d) {
+// Scalar does not define CombineShiftRightBytes.
+#if HWY_TARGET != HWY_SCALAR || HWY_IDE
     constexpr int kMaxBytes = HWY_MIN(16, int(MaxLanes(d) * sizeof(T)));
-    TestCombineShiftRightBytesR<kMaxBytes - 1>()(t, d);
-    TestCombineShiftRightLanesR<kMaxBytes / int(sizeof(T)) - 1>()(t, d);
+    constexpr int kMaxLanes = kMaxBytes / static_cast<int>(sizeof(T));
+    TestCombineShiftRightBytes<kMaxBytes - 1>()(t, d);
+    TestCombineShiftRightBytes<HWY_MAX(kMaxBytes / 2, 1)>()(t, d);
+    TestCombineShiftRightBytes<1>()(t, d);
+
+    TestCombineShiftRightLanes<kMaxLanes - 1>()(t, d);
+    TestCombineShiftRightLanes<HWY_MAX(kMaxLanes / 2, -1)>()(t, d);
+    TestCombineShiftRightLanes<1>()(t, d);
+#else
+    (void)t;
+    (void)d;
+#endif
   }
 };
 
@@ -553,11 +542,13 @@ class TestSpecialShuffle32 {
   }
 
  private:
+  // HWY_INLINE works around a Clang SVE compiler bug where all but the first
+  // 128 bits (the NEON register) of actual are zero.
   template <class D, class V>
-  HWY_NOINLINE void VerifyLanes32(D d, VecArg<V> actual, const size_t i3,
-                                  const size_t i2, const size_t i1,
-                                  const size_t i0, const char* filename,
-                                  const int line) {
+  HWY_INLINE void VerifyLanes32(D d, VecArg<V> actual, const size_t i3,
+                                const size_t i2, const size_t i1,
+                                const size_t i0, const char* filename,
+                                const int line) {
     using T = TFromD<D>;
     constexpr size_t kBlockN = 16 / sizeof(T);
     const size_t N = Lanes(d);
@@ -582,10 +573,12 @@ class TestSpecialShuffle64 {
   }
 
  private:
+  // HWY_INLINE works around a Clang SVE compiler bug where all but the first
+  // 128 bits (the NEON register) of actual are zero.
   template <class D, class V>
-  HWY_NOINLINE void VerifyLanes64(D d, VecArg<V> actual, const size_t i1,
-                                  const size_t i0, const char* filename,
-                                  const int line) {
+  HWY_INLINE void VerifyLanes64(D d, VecArg<V> actual, const size_t i1,
+                                const size_t i0, const char* filename,
+                                const int line) {
     using T = TFromD<D>;
     constexpr size_t kBlockN = 16 / sizeof(T);
     const size_t N = Lanes(d);
@@ -600,19 +593,19 @@ class TestSpecialShuffle64 {
 };
 
 HWY_NOINLINE void TestAllSpecialShuffles() {
-  const ForGE128Vectors<TestSpecialShuffle32> test32;
+  const ForGEVectors<128, TestSpecialShuffle32> test32;
   test32(uint32_t());
   test32(int32_t());
   test32(float());
 
-#if HWY_CAP_INTEGER64
-  const ForGE128Vectors<TestSpecialShuffle64> test64;
+#if HWY_HAVE_INTEGER64
+  const ForGEVectors<128, TestSpecialShuffle64> test64;
   test64(uint64_t());
   test64(int64_t());
 #endif
 
-#if HWY_CAP_FLOAT64
-  const ForGE128Vectors<TestSpecialShuffle64> test_d;
+#if HWY_HAVE_FLOAT64
+  const ForGEVectors<128, TestSpecialShuffle64> test_d;
   test_d(double());
 #endif
 }
